===============================================================
Visualization of Elephant -  Electrophysiology Analysis Toolkit
===============================================================

A Python module for easy visualization of Neo_ objects and Elephant_ results.

Viziphant provides a high-level API to easily generate plots and interactive
visualizations of neuroscientific data and analysis results. This API uses and
extends the same structure as in Elephant to ensure intuitive usage for
scientists that are used to Elephant.


.. toctree::
   :maxdepth: 1

   install
   modules
   release_notes
   authors
   acknowledgments


.. _Elephant: https://elephant.readthedocs.io/
.. _Neo: http://neuralensemble.org/neo/
